***************************************************************************************************************************
*Title: Chapter 4 Plum Detail Batch
*Data: Plumagencydet.dta
*Date: July 18, 2007

*Description: This do file has the commands for the detailed Plum Book agency data. It 
*takes care of some problems in the Plum Book data (described below) and shows the commands used to determine
*changes in appointee percentages over time. 

*Note: Tables 4.1 to 4.3 in Chapter 4 look at selected agencies, not all agencies. I tried to focus on those 
*that would be most familiar to readers.

**************************************************************************************************************************************************************************************************************************************************************
*There are a number of oddities in the data derived from using simple counts in the Plum Books and these oddities
*need to be addressed to make proper inferences.

*First, some agencies in the EOP, namely the WHO, NSC, Office of Administration, and 
*Office of Policy Development, and Executive Mansion and Grounds have counts that do 
*not reflect that fact that they are all appointees. Each of these EOP units has data that do not reflect
*the true degree of personnel control and the political appointments data is more or less
*meaningless.
*
*Second, the National Mediation Board (#890) has a 36, 0,48 sequence for Schedule C appointees in 60, 64, 68.
*
*Third, the Panama Canal Commission (#1140) goes from 1 to 5 PAS slots in the 1992-6 period.
*
*Fourth, the AG department (#25000) switches Schedule A slots to Schedule C slots in the mid 1960s leading to an 
*uptick in Schedule C.  The schedule A slots bounce around a ton before that.
*
*Fifth, the Peace Corps goes from 0 to 28 Schedule C positions in 1992 and then back to 0 in 1996. 
*I have changed this in the dataset so that these are PL/XS positions. In the 1992 Plum book they are 
*listed as NA but in the foreign service.
*
*Sixth, the Selective Service (#1230) goes from 53 to 1 PA from 1960 to 1964.  In 1964 the PA positions were 
*reclassified as Schedule A.  
*
*Seventh, Action (#10) goes from 0 to 49 PA in 1976 and back to 0 in 1980.  These were foreign service positions 
*in the Peace Corps. They are coded as PL in 1980 and 1972.  I have changed them to PL in the data.
*
*Eight, Labor (#35000) makes a big jump in 1980 from 1976
*
*Ninth, HEW (#31000) makes a big jump in appointees and employment in 1972 also
*
*Tenth, Farm Credit Administration (#490) goes down to zero in 80 and 84 and this is unlikely.
*
*Eleventh, Department of Justice (#34000) has unusually lower number of PAS appointments in 1988 relative to other years.
*
*Twelfth, the DC government has strange changes in the number of appointees (#420).
*
*Thirteenth, the EEOC (#460) is listed as having no PAS appointees in 1968 which does not seem right.
*
*Fourteenth, the IDCA (#740) has strange values for PAS across this time period.
*
*My conclusions from this for an analysis of percentages would be:
*Consider excluding PA category altogether
*Exclude WHO, NSC, Office of Administration, and Office of Policy Development or the whole EOP
*Exclude National Mediation Board prior to 1972
*Exclude Agriculture prior to 1980
*Exclude Selective Service system in 1960
*****************************************************************************************************************************

*use [insert name of Stata version of Data for Tables 4.1 to 4.3.xls]

*For a more inclusive decision rule for including cases given the concerns above I use the following commands:
drop if agencyid==890&year<1972
drop if agencyid==1230&year<1988
drop if agencyid==25000&year<1980
drop if agencyid==34000&year==1988
drop if agencyid==420
drop if agencyid==460&year==1968
drop if agencyid==740

*To exclude EOP agencies with incorrect counts
drop if agencyid==420|agencyid==1410|agencyid==470|agencyid==910|agencyid==1070|agencyid==960

*For a more exclusive decision rule for including cases given the concerns above I add the following commands:
*drop if agencyid==1140|agencyid==10|agencyid==490|agencyid==31000&year==1980|agencyid==31000&year==1972

*To exclude PA appointments I use the following command:
*drop totalpa
*drop papct
*generate totalpa=pas+schc+nea+na
*generate papct=(totalpa/emp)*100

*The following commands are used to generate the change measures.
sort agencyid2 year
by agencyid2: generate dtotal=totalpa-totalpa[_n-1]
by agencyid2: generate dpa=papct-papct[_n-1]
by agencyid2: generate dpas=pas-pas[_n-1]
by agencyid2: generate dpol=polpct-polpct[_n-1]

*To compare 2000 to 2004 I use the following commands.
drop if year<2000
sort dpa
list agency dpa dtotal pas schc na nea emp if dpa~=.
